Config

Struct Config 

#[non_exhaustive]
pub struct Config {
Show 13 fields pub lintspec: BaseConfig, pub output: OutputConfig, pub constructors: WithParamsRules, pub contracts: ContractRules, pub interfaces: ContractRules, pub libraries: ContractRules, pub enums: WithParamsRules, pub errors: WithParamsRules, pub events: WithParamsRules, pub functions: FunctionConfig, pub modifiers: WithParamsRules, pub structs: WithParamsRules, pub variables: VariableConfig,
}
The parsed and validated config for the tool

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
lintspec: BaseConfig

General config for the tool

output: OutputConfig

Output config for the tool

constructors: WithParamsRules

Validation rules for constructors

contracts: ContractRules

Validation rules for contracts

interfaces: ContractRules

Validation rules for interfaces

libraries: ContractRules

Validation rules for libraries

enums: WithParamsRules

Validation rules for enums

errors: WithParamsRules

Validation rules for errors

events: WithParamsRules

Validation rules for events

functions: FunctionConfig

Validation rules for functions

modifiers: WithParamsRules

Validation rules for modifiers

structs: WithParamsRules

Validation rules for structs

variables: VariableConfig

Validation rules for state variables

Implementations

Source

impl Config

pub fn builder() -> ConfigBuilder

Create an instance of Config using the builder syntax

Source

impl Config

pub fn from(provider: impl Provider) -> Result<Config, Box<Error>>

pub fn figment(config_path: Option<PathBuf>) -> Figment

Create a Figment which reads the config from the default file and environment variables