Definition

Enum Definition 

pub enum Definition {
    Contract(ContractDefinition),
    Interface(InterfaceDefinition),
    Library(LibraryDefinition),
    Constructor(ConstructorDefinition),
    Enumeration(EnumDefinition),
    Error(ErrorDefinition),
    Event(EventDefinition),
    Function(FunctionDefinition),
    Modifier(ModifierDefinition),
    Struct(StructDefinition),
    Variable(VariableDeclaration),
    NatspecParsingError(ErrorKind),
}
A source item’s definition

Variants

Implementations

Source

impl Definition

pub const fn is_contract(&self) -> bool

Returns true if this value is of type Contract. Returns false otherwise

pub const fn is_interface(&self) -> bool

Returns true if this value is of type Interface. Returns false otherwise

pub const fn is_library(&self) -> bool

Returns true if this value is of type Library. Returns false otherwise

pub const fn is_constructor(&self) -> bool

Returns true if this value is of type Constructor. Returns false otherwise

pub const fn is_enumeration(&self) -> bool

Returns true if this value is of type Enumeration. Returns false otherwise

pub const fn is_error(&self) -> bool

Returns true if this value is of type Error. Returns false otherwise

pub const fn is_event(&self) -> bool

Returns true if this value is of type Event. Returns false otherwise

pub const fn is_function(&self) -> bool

Returns true if this value is of type Function. Returns false otherwise

pub const fn is_modifier(&self) -> bool

Returns true if this value is of type Modifier. Returns false otherwise

pub const fn is_struct(&self) -> bool

Returns true if this value is of type Struct. Returns false otherwise

pub const fn is_variable(&self) -> bool

Returns true if this value is of type Variable. Returns false otherwise

pub const fn is_natspec_parsing_error(&self) -> bool

Returns true if this value is of type NatspecParsingError. Returns false otherwise

Source

impl Definition

pub fn to_contract(self) -> Option<ContractDefinition>

Convert to the inner contract definition.

pub fn as_contract(&self) -> Option<&ContractDefinition>

Reference to the inner contract definition.

pub fn to_interface(self) -> Option<InterfaceDefinition>

Convert to the inner interface definition.

pub fn as_interface(&self) -> Option<&InterfaceDefinition>

Reference to the inner interface definition.

pub fn to_library(self) -> Option<LibraryDefinition>

Convert to the inner library definition.

pub fn as_library(&self) -> Option<&LibraryDefinition>

Reference to the inner library definition.

pub fn to_constructor(self) -> Option<ConstructorDefinition>

Convert to the inner constructor definition.

pub fn as_constructor(&self) -> Option<&ConstructorDefinition>

Reference to the inner constructor definition.

pub fn to_enumeration(self) -> Option<EnumDefinition>

Convert to the inner enumeration definition.

pub fn as_enumeration(&self) -> Option<&EnumDefinition>

Reference to the inner enumeration definition.

pub fn to_error(self) -> Option<ErrorDefinition>

Convert to the inner error definition.

pub fn as_error(&self) -> Option<&ErrorDefinition>

Reference to the inner error definition.

pub fn to_event(self) -> Option<EventDefinition>

Convert to the inner event definition.

pub fn as_event(&self) -> Option<&EventDefinition>

Reference to the inner event definition.

pub fn to_function(self) -> Option<FunctionDefinition>

Convert to the inner function definition.

pub fn as_function(&self) -> Option<&FunctionDefinition>

Reference to the inner function definition.

pub fn to_modifier(self) -> Option<ModifierDefinition>

Convert to the inner modifier definition.

pub fn as_modifier(&self) -> Option<&ModifierDefinition>

Reference to the inner modifier definition.

pub fn to_struct(self) -> Option<StructDefinition>

Convert to the inner struct definition.

pub fn as_struct(&self) -> Option<&StructDefinition>

Reference to the inner struct definition.

pub fn to_variable(self) -> Option<VariableDeclaration>

Convert to the inner variable definition.

pub fn as_variable(&self) -> Option<&VariableDeclaration>

Reference to the inner variable definition.

pub fn to_natspec_parsing_error(self) -> Option<ErrorKind>

Convert to the inner natspec_parsing_error definition.

pub fn as_natspec_parsing_error(&self) -> Option<&ErrorKind>

Reference to the inner natspec_parsing_error definition.

Source

impl Definition

pub fn span(&self) -> Option<TextRange>

Retrieve the span of a definition

pub fn span_mut(&mut self) -> Option<&mut TextRange>

Mutably borrow the span of a definition