LintspecVisitor

Struct LintspecVisitor 

pub struct LintspecVisitor<'ast> { /* private fields */ }
Available on crate feature solar only.
A custom visitor to extract definitions from the solar_parse AST

Most of the items are visited using solar’s default Visit implementation.

Implementations

Source

impl<'ast> LintspecVisitor<'ast>

pub fn new(sess: &'ast Session) -> Self

Construct a new visitor

pub fn definitions(&self) -> &Vec<Definition>

Retrieve the found definitions

This is empty until the AST has been visited with LintspecVisitor::visit_source_unit.

Note that the spans for each definition and their corresponding members/params/returns only contain the utf8 byte offset but no line/column information. These can be populated with complete_text_ranges.