pub struct TextIndex {
pub utf8: usize,
pub line: u32,
pub col_utf8: u32,
pub col_utf16: u32,
pub col_utf32: u32,
}Expand description
A position inside of the source code
Lines and columns start at 0.
Fields
utf8: usizeByte offset from the start of the document
line: u32Line number (0-based)
col_utf8: u32Column offset in bytes (0-based)
col_utf16: u32Column offset in UTF-16 code units (0-based)
col_utf32: u32Column offset in UTF-32 code points (0-based)
This is the same as Rust’s char count.
Implementations
Sourceimpl TextIndex
impl TextIndex
Sourcepub fn advance(&mut self, c: char, next: Option<&char>)
pub fn advance(&mut self, c: char, next: Option<&char>)
Advance the index, accounting for lf/nl/ls/ps characters and combinations.
This is not derived from the definition of ‘newline’ in the language definition, nor is it a complete implementation of the Unicode line breaking algorithm.
Implementation inspired by slang_solidity.