Module utils

Module utils 

Available on crate feature slang only.
Utils for parsing Solidity source code.

Re-exports

pub use semver;

Functions

detect_solidity_version
Search for pragma solidity statements in the source and return the highest matching Solidity version.
get_latest_supported_version
Get the latest Solidity version supported by the slang_solidity parser